import { AccordionVariantType } from '@nuskin/foundation-ui-components';
import { fireEvent, render } from '@testing-library/react';

import cleanItems from '../utils/cleanItems';
import CsAccordion from '../CsAccordion';
import { SampleAccordionData } from './fixtures/CsAccordionData';
import { CsAccordionItem } from '../types/types';

describe('NsAccordion', () => {
    beforeEach(() => {
        console.error = jest.fn();
    });
    it('1. should render the component correctly', () => {
        const props = {
            level: 1,
            variant: 'basic' as AccordionVariantType,
            multiple_open: false,
            items: SampleAccordionData as CsAccordionItem[],
            invert: false
        };
        const { container } = render(<CsAccordion {...props} />);
        expect(container).toBeInTheDocument();
    });

    it('2. cleanItems function working as expected', () => {
        const result = cleanItems(SampleAccordionData as CsAccordionItem[]);
        expect(result[0].title).toEqual(SampleAccordionData[0].item_title);
    });

    it('3. should open and close the accordion when clicked', () => {
        const props = {
            level: NaN,
            variant: undefined as any,
            multiple_open: false,
            items: SampleAccordionData as CsAccordionItem[],
            invert: false
        };
        const { getByText, container } = render(<CsAccordion {...props} />);
        const accordionTitle = getByText(SampleAccordionData[0].item_title);
        fireEvent.click(accordionTitle);
        expect(accordionTitle?.closest('.section-header')).toHaveClass('expanded');
        fireEvent.click(accordionTitle);
        expect(accordionTitle?.closest('.section-header')).not.toHaveClass('expanded');
    });
});
