/* eslint-disable @next/next/no-img-element */
import { CslpTag } from '@nuskin/foundation-ui-components';

import { getTransformedMediaUrl } from './utils';
import { parseJsonString } from '../utils';
import { BynderImageDataType } from '../utils/bynder-util';

type BynderImageProps = {
    imageText: string;
    suffix?: string;
    className?: string;
    testId?: string;
    liveTag?: CslpTag;
};
export const BynderImage = ({
    imageText = '',
    suffix,
    className,
    testId,
    liveTag
}: BynderImageProps) => {
    const imageJson = parseJsonString(imageText);
    const image: BynderImageDataType = imageJson?.image?.[0] || {};
    const { fit, position, altText = '', bgColor, type } = image?.selected ?? {};
    const transformedMediaUrl = getTransformedMediaUrl(imageText, suffix);
    if (type === 'VIDEO') {
        return (
            <div {...liveTag}>
                <video
                    loop
                    autoPlay
                    muted
                    width="100%"
                    style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
                    className={`${className || ''} bynder-image`}
                    data-testid={testId || 'test-bynder-video'}
                >
                    <source src={transformedMediaUrl} type="video/mp4" />
                    <source src={transformedMediaUrl} type="video/ogg" />
                </video>
            </div>
        );
    }
    return (
        <img
            {...liveTag}
            data-testid={testId || 'test-bynder-image'}
            className={`${className || ''} bynder-image`}
            src={transformedMediaUrl}
            alt={altText}
            style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
        />
    );
};
