/* eslint-disable @next/next/no-img-element */
import { CslpTag } from '@nuskin/foundation-ui-components';
import { BynderImageDataType, getImageType, getMediaUrl, getUrlBasedOnDerivative } from '../utils/bynder-util';

type BynderMediaProps = {
    imageDetail: BynderImageDataType;
    suffix?: string;
    className?: string;
    testId?: string;
    liveTag?: CslpTag;
};
export const BynderMedia = ({
    imageDetail,
    suffix,
    className,
    testId,
    liveTag
}: BynderMediaProps) => {
    const { files, name, selected, previewUrls, isPublic } = imageDetail;
    const { url = '', fit, position, altText = '', bgColor, type } = selected ?? {};
    const imageDerivativeType = getImageType(url, name, files);
    const mediaUrl = getMediaUrl(selected, isPublic, previewUrls);
    let transformedMediaUrl = getUrlBasedOnDerivative(mediaUrl, imageDerivativeType, suffix ?? '');
    if (type === 'VIDEO') {
        return (
            <video
                loop
                autoPlay
                muted
                width="100%"
                {...liveTag}
                style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
                className={`${className || ''} bynder-image`}
                data-testid={testId || 'test-bynder-video'}
            >
                <source src={transformedMediaUrl} type="video/mp4" />
                <source src={transformedMediaUrl} type="video/ogg" />
            </video>
        );
    }
    return (
        <img
            {...liveTag}
            data-testid={testId || 'test-bynder-image'}
            className={`${className || ''} bynder-image`}
            src={transformedMediaUrl}
            alt={altText}
            style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
        />
    );
};
