/* eslint-disable no-unused-vars */
import { AllColorKeyType } from '@nuskin/foundation-theme';
import { CslpTag } from '@nuskin/foundation-ui-components';
import { Variants as FontVariants } from '@nuskin/foundation-ui-components/src/common/typography/types';

// Todo remove and make it common
export type LiveTags<T> = Omit<Record<keyof T, CslpTag>, 'liveTags' | 'renderH1' | 'dataTestId'>;
export type AlignType = 'left' | 'right';
export type CtaLinkItemProps = {
    url?: string;
    text?: string;
    color?: 'primary' | 'secondary';
    variants?: string;
    ctaVariant?: 'primary' | 'secondary';
    values?: {
        outlined?: boolean;
        align?: AlignType;
    };
    displayName?: string;
    btnVariant?: 'outlined' | 'contained';
};

export type BannerProps = {
    show: boolean;
    header: string;
    description: string;
    font_color: boolean;
    image: string;
    background_color: string;
    call_to_action: string;
};

export type HeroVariantProps = {
    hero_banner?: HeroBannerProps;
    split_banner?: SplitBannerProps;
};

export type HeroBannerProps = {
    text_alignment?:string;
    background_scrim?:boolean;
} & BannerProps;

export type SplitBannerProps = {
    theme?:string;
    image_alignment?: string;
} & BannerProps;

export interface SplitBannerItemProps {
    show: boolean;
    image: string;
    showImage?:boolean;
    imageAlignment?: 'left' | 'right';
    header?: string;
    titleFontSize?: FontVariants;
    description?: string;
    theme?: SplitBannerModes;
    fontColor?: boolean;
    backgroundColor: AllColorKeyType;
    callToAction?: CtaLinkItemProps;
    renderH1?: boolean;
    liveTags?: Record<keyof SplitBannerItemProps, CslpTag>;
    dataTestId?: string;
}

export interface BaseHeroProps {
    title?: string;
    description?: string;
    fontColor?: boolean;
    backgroundColor: AllColorKeyType;
    backgroundScrim?: boolean;
    image: string;
    showImage?: boolean;
    imageAltText?: string;
    callToAction?: CtaLinkItemProps;
    renderH1?: boolean;
    dataTestId?: string;
}

export type AlignmentType = 'start' | 'center' | 'end';

export enum SplitBannerModes {
    default = 'default',
    hero = 'hero'
}
export interface HeroBannerItemProps extends BaseHeroProps {
    header?: string;
    description?: string;
    fontColor?: boolean;
    textAlignment?: AlignmentType;
    backgroundScrim?: boolean;
    backgroundColor: AllColorKeyType;
    callToAction?: CtaLinkItemProps;
    liveTags?: LiveTags<HeroBannerItemProps>;
}
export interface heroCardProps {
    map(arg0: (item: heroCardProps, index: number) => any): import('react').ReactNode;
    title: string;
    description: string;
    cardImage: string;
    // cardImage: BynderImageDataType;
    caption?: string;
    liveTags?: Record<string, CslpTag>;
}
export interface HeroCardProps extends BaseHeroProps {
    preHeader?: string;
    header?: string;
    renderH1?: boolean;
    dataTestId?: string;
    liveTags?: LiveTags<HeroCardProps>;
    $?: Record<string, CslpTag>;
}

export interface ThreeCardsProps {
    cards: HeroCardProps[];
    renderH1?: boolean;
    dataTestId?: string;
    liveTags?: LiveTags<ThreeCardsProps>;
}

export interface ThreeCardHero {
    type: string;
    show: boolean;
    full_width: boolean;
    container_background_color: AllColorKeyType;
    include_gap: boolean;
    main_hero_card: MainHeroCard;
    sub_hero_1: SubHero1;
    sub_hero_2: SubHero2;
}
export interface WebImageProps {
    webImage: string;
}
export interface ImageProps {
    $: {
        url?: CslpTag;
    };
    derivatives: WebImageProps;
}
export interface MainHeroCard {
    header: string;
    description: string;
    font_color: boolean;
    background_scrim: boolean;
    background_color: AllColorKeyType;
    image: ImageProps[];
    image_alt_text: string;
    call_to_action: string;
    $?: Record<keyof MainHeroCard, CslpTag>;
}
export interface SubHero1 {
    pre_header: string;
    header: string;
    font_color: boolean;
    background_scrim: boolean;
    background_color: AllColorKeyType;
    image: ImageProps[];
    image_alt_text: string;
    call_to_action: string;
    $?: Record<keyof SubHero1, CslpTag>;
}

export interface SubHero2 {
    pre_header: string;
    header: string;
    font_color: boolean;
    background_scrim: boolean;
    background_color: AllColorKeyType;
    image: ImageProps[];
    image_alt_text: string;
    call_to_action: string;
    $?: Record<keyof SubHero2, CslpTag>;
}

/* eslint-disable no-unused-vars */
export enum HeroTypeName {
    heroComponent = 'hero_component',
    show = 'show',
    title = 'title',
    titleFontSize = 'title_font_size',
    _content_type_uid = '_content_type_uid  ',
    text = 'text',
    href = 'href',
    image = 'image',
    imageAltText = 'image_alt_text',
    imageAlignment = 'image_alignment',
    fullViewImage = 'full_column_image',
    heroImage = 'hero_image',
    buttonSize = 'button_size',
    buttonType = 'button_type',
    contentAlignment = 'content_alignment',
    contentPosition = 'content_position',
    fontColor = 'font_color',
    textAlignment = 'text_alignment',
    header = 'header',
    heroSubtitle = 'hero_subtitle',
    heroTitle = 'hero_title',
    tagline = 'tagline',
    cta = 'cta',
    heroColumns = 'hero_columns',
    threeColumnHeroImage = 'three_column_image',
    imageHeight = 'height',
    textOverrideColor = 'text_override_color',
    callToAction = 'call_to_action',
    highlightBlock = 'highlight_block',
    highlightBlockTitle = 'highlight_block_title',
    highlightBlockDescription = 'highlight_block_description',
    backgroundColor = 'background_color',
    backgroundScrim = 'background_scrim',
    highlightBlockCallToAction = 'call_to_action',
    preHeader = 'pre_header',
    url = 'url',
    link = 'link',
    linkItem = 'link_item',
    groupedCards = 'grouped_cards',
    videoBackground = 'video_background',
    card_count = 'card_count',
    cards = 'cards',
    heroCards = 'hero_cards',
    description = 'description',
    groupedCardsCall_ToAction = 'call_to_action',
    buttonColor = 'button_color',
    cardImage = 'card_image',
    altText = 'alt_text',
    imgCaption = 'img_caption',
    showCaseHero = 'show_case_hero',
    ctaVariant = 'cta_variant',
    ctaColor = 'cta_color',
    ctaText = 'cta_text',
    ctaTarget = 'cta_target',
    ctaLink = 'cta_link',
    imgAlignment = 'img_alignment',
    variant = 'variant',
    cardTitle = 'card_title',
    cardDescription = 'card_description',
    accentImage = 'accent_image',
    showCaseListItems = 'show_case_list_items',
    cardBackgroundColor = 'card_background_color',
    bulletBackground = 'bullet_background',
    bulletTickColor = 'bullet_tick_color',
    theme = 'theme'
}

export enum HeroVariants {
    HeroBanner = 'hero_banner',
    ThreeCards = 'three_cards',
    SplitBanner = 'split_banner'
}