import { AllColorKeyType, styled } from '@nuskin/foundation-theme';
import { getGenomeColor } from '@nuskin/foundation-theme/src/common/themes/genome-colors/ColorFunctions';
import Link from 'next/link';

import { HeroContentContainer, HeroImageContainer, HeroTextContainer } from '../../helper-components/HeroCommon.styled';
import { breakpoints } from '../../../theme';
import ABSOLUTE_FILL from '../../../theme/styles';

/**
 * Renders a tint over the image when a parent container has .with-scrim class
 */
export const ImageContainer = styled(HeroImageContainer)`
    position: relative;
    height: 310px;
    width: 100%;

    img {
        height: 100%;
        width: 100%;
        float: right;
        object-fit: cover;
        object-position: center;
        ::after {
            clear: both;
        }
    }
    ::after {
        content: ' ';
        display: block;
        clear: both;
    }

    .with-scrim &::before {
        ${ABSOLUTE_FILL}
        content: " ";
        display: block;
        background-color: #00000040;
    }

    .sub-card & {
        ${ABSOLUTE_FILL}
    }

    ${breakpoints.md} {
        ${ABSOLUTE_FILL}
        height: 100%;
        img {
            float: none;
            margin: 0;
            width: 100%;
            height: 100%;
        }
    }
`;

export const TextContainer = styled(HeroTextContainer)`
    padding: 30px;
    width: 100%;
    height: 100%;
    overflow: hidden;
    z-index: 1;

    button {
        margin-top: 30px;
    }

    ${breakpoints.md} {
        position: relative;
        z-index: 1;
        width: 55%;
        text-align: left;

        .main-card & {
            padding: 60px;
        }
    }

    ${breakpoints.lg} {
        width: 50%;
    }
`;
export const ContentContainer = styled(HeroContentContainer)<{ backgroundColor: AllColorKeyType }>`
    align-items: center;
    height: 100%;
    width: 100%;
    overflow: hidden;
    position: relative;

    background-color: ${({ backgroundColor, theme }) => getGenomeColor(theme, backgroundColor)};
    ${breakpoints.md} {
        flex-direction: row;
    }
`;

export const ThreeCardLayout = styled.div`
    & > * {
        overflow: hidden;
    }

    & .sub-card {
        height: 230px;
    }

    ${breakpoints.md} {
        display: grid;
        grid-template-columns: repeat(10, 1fr);
        grid-template-rows: repeat(2, 1fr);
        gap: 10px;

        & .main-card {
            grid-column: 1 / 11;
            grid-row: 1 / 2;
            height: 480px;
        }

        & .sub-card:nth-of-type(2) {
            grid-column: 1 / 6;
            grid-row: 2 / 3;
        }

        & .sub-card:nth-of-type(3) {
            grid-column: 6 / 11;
            grid-row: 2 / 3;
        }
    }

    ${breakpoints.lg} {
        & .main-card {
            grid-column: 1 / 7;
            grid-row: 1 / 3;
        }

        & .sub-card {
            height: 100%;
        }

        & .sub-card:nth-of-type(2) {
            grid-column: 7 / 11;
            grid-row: 1 / 2;
        }

        & .sub-card:nth-of-type(3) {
            grid-column: 7 / 11;
            grid-row: 2 / 3;
        }
    }
`;

export const StyledLink = styled(Link)`
    display: block;
    height: 100%;
    width: 100%;
    position: relative;
    text-decoration: none;
`;
