import { renderHook } from '@testing-library/react';
import useScreenSize from '../useScreenSize';

describe('useScreenSize', () => {
    let originalWindow: any;

    beforeAll(() => {
        originalWindow = { ...window };
    });

    beforeEach(() => {
        // Reset window object before each test
        window.innerWidth = 1024;
        window.innerHeight = 768;
        window.addEventListener = jest.fn();
        window.removeEventListener = jest.fn();
    });

    afterAll(() => {
        // Restore original window object after all tests
        Object.assign(window, originalWindow);
    });

    it('should return initial screen size', () => {
        const { result } = renderHook(() => useScreenSize());

        expect(result.current.width).toBe(1024);
        expect(result.current.height).toBe(768);
    });

    test('should add event listener on mount and remove on unmount', () => {
        const { unmount } = renderHook(() => useScreenSize());

        expect(window.addEventListener).toHaveBeenCalledWith('resize', expect.any(Function));
        unmount();
        expect(window.removeEventListener).toHaveBeenCalledWith('resize', expect.any(Function));
    });
});
