import { useEffect, useState } from 'react';

/**
 *
 * @param val value that you want to debounce
 * @param delay delay in milliseconds.
 * @returns The hook returns the debouncedValue, 
 * which will be the latest value after the specified delay has passed without any further updates.
 */

const useDebounce = <T>(value: T, delay: number): T => {
    const [debouncedValue, setDebouncedValue] = useState(value);

    useEffect(() => {
        const timer = setTimeout(() => {
            setDebouncedValue(value);
        }, delay);

        return () => {
            clearTimeout(timer);
        };
    }, [value, delay]);

    return debouncedValue;
};

export default useDebounce;
