import { useRouter } from 'next/router';

import type { EquinoxPageType } from '../config/equinoxRouteConfig';
import EquinoxPages from '../config/equinoxRouteConfig';
import type { FoundationPageType } from '../config/routeConfig';
import FoundationPages from '../config/routeConfig';
import { getRegionAndLanguageFromQuery, isBrowser } from '../utils';

export type PageRoutesType = EquinoxPageType | FoundationPageType | string;

const usePageRoutes = () => {
    const router = useRouter();
    const { region, language } = getRegionAndLanguageFromQuery(router.query) || {};

    const getUrl = (page: PageRoutesType, path?: string, options?: { withOrigin: boolean }) => {
        let url = '';
        let attachOrigin = options?.withOrigin || false;
        if (page in FoundationPages) {
            const pageName = FoundationPages[page as FoundationPageType];
            const pathName = path ? `/${path}` : '';
            const pageWithPath = pageName ? `${pageName}${pathName}` : path;
            url += `/${region}/${language}/site/${pageWithPath}`;
        } else if (page in EquinoxPages) {
            const pageName = EquinoxPages[page as EquinoxPageType];
            const pathName = path ? `/${path}` : '';
            const pageWithPath = pageName ? `${pageName}${pathName}` : path;
            attachOrigin = true;
            url += `${region}/${language}/${pageWithPath}`;
        } else if (path && !/^https?:\/\//.test(path)) {
            attachOrigin = true;
            url = path;
        } else if (path) {
            url = path;
        }
        if (isBrowser() && attachOrigin) {
            const origin = window?.location?.origin || '';
            url = `${origin}/${url}`;
        }
        return url;
    };

    const navigate = (page: PageRoutesType, path?: string) => {
        if (page in FoundationPages) {
            const url = getUrl(page, path);
            if (url) {
                router.push(url);
            }
        } else if (page in EquinoxPages) {
            const url = getUrl(page, path);
            if (url) {
                window.location.href = url;
                // window?.location?.replace(url);
            }
        } else {
            //logic is that if it's in foundation , we will use router.push . if it's not then we won't use router.push since router.push will append to the existing domain name and 404 will be rendered for other pages, we will replace the page so that full page refresh will take place
            // window?.location?.replace(page);
            window.location.href = page;
        }
    };

    return {
        navigate,
        getUrl
    };
};

export default usePageRoutes;
