import { useRouter } from 'next/router';

import {
    getRegionAndLanguageFromQuery,
    replaceRegionAndLanguage
} from '../utils';

/**
 * Simply use this hook to update the region and language in the url
 * Note: urlToParse should have {%region} or {%language} or {%rREGION} or {%LANGUAGE}
 * @param urlToParse url to be parsed
 * @returns urlToParse after conditionally replacing the region and language
 */
const useRouteReplacer = (urlToParse?: string) => {
    const { query } = useRouter();
    const replacer = getRegionAndLanguageFromQuery(query);
    const url = urlToParse ? replaceRegionAndLanguage(urlToParse, replacer) : undefined;
    return { url };
};

export default useRouteReplacer;
