import { NsHero, ThreeCardHero, getThreeCardData } from '../hero';
import AdditionalComponentParser from './components/additional-components/AdditionalComponentParser';
import RefComponentParser from './components/reference-components/RefComponentParser';
import { ComponentBlockType } from '../types';
import { NsShowcaseComponent } from '../showcase';
import { NsVideo } from '@nuskin/foundation-ui-components';
import { CsCard } from '../card';
import { NsAccordian } from '../accordion';
import { CsPageTitle } from '../page-title';
import { NsStatement } from '../statement';

export type BodyBlockMapType = Record<string, ComponentBlockType>;

export const GlobalFieldMap: { [key: string]: string } = {
    ns_hero_global: 'ns_hero',
    ns_video_component: 'ns_video',
    ns_carousel_component: 'ns_carousel',
    accordion: 'ns_accordion'
};

export const dataParser = (props: any) => props;

export const BodyBlockMap: BodyBlockMapType = {
    ns_hero: {
        dataParser,
        component: NsHero
    },
    component_reference: {
        dataParser,
        component: RefComponentParser
    },
    additional_component: {
        component: AdditionalComponentParser,
        dataParser
    },
    ns_showcase: {
        dataParser,
        component: NsShowcaseComponent
    },
    ns_accordion: {
        dataParser,
        component: NsAccordian
    },
    ns_video: {
        dataParser,
        component: NsVideo
    },
    ns_card: {
        dataParser,
        component: CsCard
    },
    ns_three_card_hero: {
        dataParser: getThreeCardData,
        component: ThreeCardHero
    },
    ns_page_title: {
        dataParser,
        component: CsPageTitle
    },
    ns_statement: {
        dataParser,
        component: NsStatement
    }
};
