import { render } from '@testing-library/react';

import { SHOWCASE_LIST } from '../fixtures/Showcase';
import Showcase, { ShowCaseListProps } from './ShowcaseList';

const renderComponent = (props: ShowCaseListProps) => render(<Showcase {...props} />);

describe('Ns Showcase - Showcase List', () => {
    describe('positive tests', () => {
        const positiveTests = ['show-case-list-image', 'showcase-list-title'];

        positiveTests.forEach((testId) => {
            it(`Should render the ${testId}`, () => {
                const { queryByTestId } = renderComponent(SHOWCASE_LIST);
                const el = queryByTestId(testId);
                expect(el).toBeInTheDocument();
            });
        });

        it('Should render 4 list items', () => {
            const { queryAllByTestId } = renderComponent(SHOWCASE_LIST);
            const el = queryAllByTestId('show-case-list-item');
            expect(el.length).toBe(4);
        });
    });

    describe('negative tests', () => {
        const negativeTests = [
            {
                prop: 'title',
                testId: 'showcase-list-title'
            },
            {
                prop: 'entries',
                testId: 'show-case-list-item'
            }
        ];

        negativeTests.forEach(({ prop, testId }, index) => {
            it(`${index}. Given without ${prop} Should not render the ${prop}`, () => {
                const { queryByTestId } = renderComponent({
                    ...SHOWCASE_LIST,
                    [prop]: undefined
                });
                const el = queryByTestId(testId);
                expect(el).not.toBeInTheDocument();
            });
        });
    });
});
