import { styled } from '@nuskin/foundation-theme';
import { NsTypography } from '@nuskin/foundation-ui-components';

import { ShowcaseContentContainer, ShowcaseTextContainer } from '../ShowcaseCommon.styled';
import { breakpoints } from '../../../theme';

export const ShowcaseDefaultTextContainer = styled(ShowcaseTextContainer)`
    .has-accent & {
        margin-bottom: 30px;

        ${breakpoints.md} {
            margin-bottom: 100px;
        }
    }
    .showcase-header {
        font-size: 26px;
    }
    .description {
        font-size: 16px;
    }
    .ctaLink-container a {
        /*useful for secondary variant*/
        text-transform: uppercase;
    }
    .ctaLink-container button {
        /* useful for primary variant*/
        width: 100%;
        height: 44px;
        text-transform: uppercase;
    }
    ${breakpoints.sm} {
        .ctaLink-container button {
            width: 240px;
        }
    }
    ${breakpoints.md} {
        .showcase-header {
            font-size: 36px;
        }
        .description {
            font-size: 18px;
        }
    }
`;
export const ShowcasePreHeader = styled(NsTypography)<{ backgroundColor: string }>`
    background-color: ${({ backgroundColor }) => backgroundColor};
    display: inline-block;
    height: 28px;
    line-height: 28px;
    margin-bottom: 20px;
    padding: 0 8px;
`;

export const ShowcaseAccentImageContainer = styled.div`
    overflow: hidden;
    height: 140px;
    width: 120px;
    position: absolute;
    bottom: -30px;
    right: 40px;

    img {
        object-fit: cover;
        height: 100%;
    }

    ${breakpoints.sm} {
        right: 120px;
    }

    ${breakpoints.md} {
        bottom: -100px;
    }

    ${breakpoints.xl} {
        right: 180px;
    }
`;

// Applying an offset to the accent overlap image
export const ShowcaseDefaultContentContainer = styled(ShowcaseContentContainer)`
    margin-bottom: 32px;

    ${breakpoints.md} {
        & > .accent-image-container {
            display: none;
        }
        margin-bottom: 0;
        &.has-accent {
            min-height: 520px;
        }
    }
`;
