import { CslpTag } from '@nuskin/foundation-ui-components';

export type EditTagKey = Record<string, { 'data-cslp'?: string }>;

export type DynamicObject = Record<string, any>;


export type CustomImageExtImage = {
    id: string;
    name: string;
    description: string;
    type: string;
    url: string;
    derivatives: {
        thumbnail: string;
        webImage: string;
        mini: string;
        'JPG Version'?: string;
        Small: string;
        'Web Image': string;
        Thumbnail: string;
        Large: string;
        $?: EditTagKey;
    };
    $?: EditTagKey;
};

// common props
export interface IconListProps {
    icons: {
        icon_url: string;
        icon_redirect_link: {
            href: string;
            title: string;
        };
    };
}

export interface IconBlockProps {
    left_block_icons: IconListProps[];
}

// Page props
export interface ForceForGoodHomePageProps {
    theme?: string;
    utility_bar: HeaderUtilityBarProps;
    header: HeaderPageProps;
    footer: FooterPageProps;
    body: any;
}

export interface HeaderUtilityBarProps {
    show_util_bar: boolean;
    utility_reference: IconBlockProps[];
}

export interface HeaderPageProps {
    ffg_header: any[];
    show_header: boolean;
}

export interface FFGHeaderProps {
    logo: {
        logo_url: string;
        logo_redirect_link: {
            href: string;
            title: string;
        };
    };
    navigation_bar: HeaderNavigationBar[];
    nav_right_block: {
        button: {
            button_link: {
                href: string;
                title: string;
            };
            button_text: string;
        };
    };
}

export interface HeaderNavigationBar {
    nav_link_item: {
        nav_item: {
            href: string;
            title: string;
        };
        title_text_options: {
            colorVariant: string;
            sizeVariant: string;
            style: string;
            weight: string;
        };
    };
}

export interface FooterPageProps {
    show_footer: boolean;
    footer_ref: IconBlockProps[];
}

export interface PageBlocksProps {
    type: string;
    show: boolean;
    full_width?: boolean;
    container_background_color?: string;
    background_image?: CustomImageExtImage[]
    include_gap?: boolean;
}

export interface RefComponentProps {
    component: {
        show: boolean;
        component: any[];
    };
    _content_type_uid: string;
}

export type ComponentBlockMapType = {
    [key: string]: {
        component: React.ElementType;
        dataParser: (props: any) => void;
    };
};

export interface RefComponentProps {
    component: {
        show: boolean;
        component: any[];
    };
    _content_type_uid: string;
}

export type ComponentBlockType = {
    component: React.ElementType;
    dataParser: (props: any) => Record<string, any>;
};

export interface BlockRefProps {
    image: any;
    image_description?: string;
    image_title?: {
        title_text: string;
    };
    navigation_button?: {
        href: string;
        title: string;
    };
}

export interface ContainerCardsProps {
    cards: {
        temp_icon_url?: string;
        title_text_options?: {
            colorVariant: string;
            sizeVariant: string;
            style: string;
            weight: string;
        };
        card_sub_text?: string;
        card_title_text?: string;
        sub_text_options: {
            colorVariant: string;
            sizeVariant: string;
            style: string;
            weight: string;
        };
    };
}

export type LiveTags<T> = Omit<Record<keyof T, CslpTag>, 'liveTags' | 'renderH1' | 'dataTestId'>;