import Router from 'next/router';
import { ParsedUrlQuery } from 'querystring';

const languageReplaceExpression = '{%language}';
const languageReplaceExpressionUppercase = '{%LANGUAGE}';
const regionReplaceExpression = '{%region}';
const regionReplaceExpressionUppercase = '{%REGION}';

type RegionLanguageQuery = {
    region?: string;
    language?: string;
};

export const replaceRegionAndLanguage = (text: string, replacer: RegionLanguageQuery = {}) => {
    if (typeof text !== 'string') {
        return '';
    }
    if (replacer?.region) {
        text = text.replace(regionReplaceExpression, replacer.region);
        text = text.replace(regionReplaceExpressionUppercase, replacer.region?.toUpperCase());
    }
    if (replacer?.language) {
        text = text.replace(languageReplaceExpression, replacer.language);
        text = text.replace(languageReplaceExpressionUppercase, replacer.language?.toUpperCase());
    }
    return text;
};

export const replacePathnameWithQueryParams = (pathname: string, queryParams: Record<string, string>) => {
    if (pathname && typeof pathname === 'string') {
        let formattedUrl = pathname;
        if (queryParams?.region) {
            formattedUrl = formattedUrl.replace('[region]', queryParams?.region);
        }
        if (queryParams?.language) {
            formattedUrl = formattedUrl.replace('[language]', queryParams?.language);
        }
        if (queryParams?.region) {
            formattedUrl = formattedUrl.replace('[[...slug]]', queryParams?.slug);
        }
        return formattedUrl;
    }
    return '';
};

export const getRegionAndLanguageFromQuery = (query: ParsedUrlQuery): RegionLanguageQuery | undefined => {
    if (query?.language || query?.region) {
        return {
            region: query?.region as string,
            language: query?.language as string,
        };
    }
};

export const getRegionAndLanguageFromRouter = (): RegionLanguageQuery | undefined => {
    const { query } = Router;
    return getRegionAndLanguageFromQuery(query);
};
